.. currentmodule:: xproj

:orphan:

.. autosummary::
   :toctree: _api_generated/
   :template: autosummary/crs_index.rst

   CRSIndex

.. autosummary::
   :toctree: _api_generated/

   ProjAccessorMixin._proj_set_crs
   ProjIndexMixin._proj_get_crs
   ProjIndexMixin._proj_set_crs
   ProjIndexMixin._proj_to_crs
   format_compact_cf
   format_full_cf_gdal
